@@ -2,6 +2,8 @@ package Test::Smoke::SysInfo::Darwin;
 use warnings;
 use strict;
 
+our $VERSION = '0.001';
+
 use base 'Test::Smoke::SysInfo::BSD';
 
 =head1 NAME
@@ -70,6 +72,7 @@ sub __get_system_profiler {
         }
     }
 
+    $system_profiler{'CPU Type'} ||= 'Unknown';
     $system_profiler{'CPU Type'} =~ s/PowerPC\s*(\w+).*/macppc$1/;
     $system_profiler{'CPU Speed'} =~
         s/(0(?:\.\d+)?)\s*GHz/sprintf("%d MHz", $1 * 1000)/e;
